Zuul API
========

The Zuul API source pulls data from the Zuul CI/CD system.

Usage
^^^^^

The following is a configuration sample of how to configure the Zuul source

.. include:: ../config_samples/zuul_api_configuration.rst

Plugin Support
^^^^^^^^^^^^^^

The Zuul source is supported by the following built-in plugins:

  * OpenStack
